import suiAnalytics from '../src'
import {expect} from 'chai'
import sinon from 'sinon'

describe('#suiAnalytics', () => {
  describe('when the track event is called', () => {
    beforeEach(() => {
      window.analytics = {}
      window.analytics = {
        ready: function(cb) {
          cb()
        },
        user: () => ({
          anonymousId: () => 'fakeAnonymousId',
          id: () => 'fakeId'
        }),
        track: sinon.stub()
      }

      window.Visitor = {}
      window.Visitor.getInstance = sinon.stub().returns({
        getMarketingCloudVisitorID: sinon.stub().returns('fakeCloudId')
      })
    })

    afterEach(() => {
      delete window.analytics
      delete window.Visitor
    })

    it('should add anonymousId as options trait', () => {
      suiAnalytics.track('fakeEvent', {fakePropKey: 'fakePropValue'})

      sinon.assert.callCount(window.analytics.track, 1)
      expect(window.analytics.track.getCall(0).args[2]).to.deep.equal({
        traits: {anonymousId: 'fakeAnonymousId', userId: 'fakeId'},
        'Adobe Analytics': {
          marketingCloudVisitorId: 'fakeCloudId'
        }
      })
    })
  })
})
